// ButtonActionListener Class
function ButtonActionListener() {
	
	// PRIVATE VARS
	var buttonList = [];
	var isDragging = false;
	var isAllButtonsDisabled = false;
	
	// PRIVATE METHODS
	function getTouchStartListener(button) {
		return function (event) { 
			if ( !isAllButtonsDisabled ) {
				isDragging = false;
				button.className += " pressed";
			}
		};
	}
	
	function getTouchMoveListener(button) {
		return function (event) {
			if ( !isAllButtonsDisabled ) {
				clearButtons(); 
				isDragging = true;
			}
		};
	}
	
	function getTouchEndListener(button) {
		return function (event) { 
			if ( !isAllButtonsDisabled ) {
				clearButtons();
				if (!isDragging) {
					disableButtons();
					window.location.href = button.getAttribute("href");				
				}
			}
		};
	}

	function getClickListener(button) {
		return function (event) { 
			event.preventDefault();
		};
	}

	function disableButtons() {
		for (var index=0; index < buttonList.length ; index++) {
			buttonList[index].disabled = true;
	    }
		isAllButtonsDisabled = true;
		window.setInterval(function(){enableButtons()}, 1000);
	}

	function enableButtons() {
		for (var index=0; index < buttonList.length ; index++) {
			buttonList[index].disabled = false;
	    }
		isAllButtonsDisabled = false;
	}

	function clearButtons() {
		for (var index=0; index < buttonList.length ; index++) {
			buttonList[index].className = buttonList[index].className.replace( /(?:^|\s)pressed(?!\S)/g , '');
	    }
	}
	
	// PRIVILEGED METHODS (can be called from public)
	this.add = function(button) {
		
		button.addEventListener("touchstart", getTouchStartListener(button), false);
		button.addEventListener("touchmove", getTouchMoveListener(button), false);
		button.addEventListener("touchend", getTouchEndListener(button), false);
		button.addEventListener("click", getClickListener(button), false);
		
		buttonList.push( button );
	}
}
// end of ButtonActionListener Class


var buttonActionListener = new ButtonActionListener();

function initButtonEventListeners() {
	for (var index=0; index<document.getElementsByTagName("button").length; index++) {
		var button = document.getElementsByTagName("button")[index];
		buttonActionListener.add( button );
	}
}


function updateButtonHref() {
	var inputFormAction = document.getElementById("inputForm").action;
	var inputText = document.getElementsByTagName("input")[0].value;
	inputText = inputText.replace(/,/g,'');
	var finalAction = inputFormAction + inputText;
	var inputButton = document.getElementsByTagName("button")[0];
	inputButton.setAttribute("href", finalAction);
	
	return inputButton;
}

function updateWindowLocation() {
	inputButton = updateButtonHref(); 
	var url = inputButton.getAttribute("href"); 
	window.location.href=url;
	event.preventDefault();
}

function initFormEventListeners() {

	var button = document.getElementsByTagName("input")[0];
	if (button != null) {
		button.addEventListener("keyup", updateButtonHref, false);
	}
	
	//ensure that default form submit is ignored
	var form = document.getElementsByTagName("form")[0];
	if (form != null) {
		form.addEventListener("submit", updateWindowLocation , false);
	}
}

window.onload=function(){
	initButtonEventListeners();
	initFormEventListeners();
};

